Learn R Programming

rworldmap (version 1.01)

getMap: A simple way to access maps stored in the package.

Description

A simple way to access maps stored in the package.

Usage

getMap(resolution = "coarse", projection=NA)

Arguments

resolution
options "coarse","low","less islands","li","high". For "high" you need to install the package rworldxtra
projection
DEPRECATED OCTOBER 2012 to reproject maps see spTransform in rgdal

Value

  • A SpatialPolygonsDataFrame object.

Examples

Run this code
plot(getMap())

Run the code above in your browser using DataLab