Learn R Programming

rworldmap (version 1.01)

mapBubbles: function to produce bubble plots on a map, size and colour determined by attribute data

Description

The function will produce a map with bubbles (circles) centred on country centroids (or other chosen points). Bubbles can be sized and coloured according to specified attribute values.

Usage

mapBubbles(dF = ""
          , nameX = "longitude"
          , nameY = "latitude"
          , nameZSize = ""
          , nameZColour = ""
          
          , fill = TRUE
          , pch = 21
          , symbolSize = 1
          , maxZVal = NA          
          
          , main = nameZSize
          
          , numCats = 5
          , catMethod = "categorical"
          , colourPalette = "heat"
          
          , mapRegion = "world"
          , borderCol = "grey"
          , oceanCol = NA
          , landCol = NA
              
          , addLegend = TRUE
          , legendBg = "white"
          , legendVals = ""
          , legendPos = "bottomright"
          , legendHoriz = FALSE
          , legendTitle = nameZSize
          , addColourLegend = TRUE
          , colourLegendPos = "bottomleft"
          , colourLegendTitle = nameZColour
          , add = FALSE
          , plotZeroVals = TRUE
          , ...)

Arguments

dF
data frame or SpatialPolygonsDataFrame
nameX
name of column containing the X variable (longitude), not needed if dF is a SpatialPolygonsDataFrame
nameY
name of column containing the Y variable (lattitude), not needed if dF is a SpatialPolygonsDataFrame
nameZSize
name of column containing numeric variable to set symbol size
nameZColour
name of column containing variable to set symbol colour
fill
whether or not to fill symbols TRUE/FALSE
pch
symbol type, default of 21 for circles, will work with other filled symbol types e.g. 22=square, 23=diamond, 24=triangle
symbolSize
multiplier of default symbol size
maxZVal
the attribute value corresponding to the maximum symbol size, this can be used to set the scaling the same between multiple plots
main
title for the map, set to nameZSize by default
numCats
number of categories to put the data in, may be modified if this number is incompatible with the catMethod chosen
catMethod
method for categorisation of data "pretty", "fixedWidth", "diverging", "logfixedWidth","quantiles","categorical", or a numeric vector defining breaks
colourPalette
a string describing the colour palette to use, choice of :
{="palette" for the current palette} {a vector of valid colours, e.g. =c('red','white','blue') or output from RColourBrewer} <

Value

  • currently doesn't return anything

item

  • mapRegion
  • borderCol
  • oceanCol
  • landCol
  • addLegend
  • legendBg
  • legendVals
  • legendPos
  • legendHoriz
  • legendTitle
  • addColourLegend
  • colourLegendPos
  • colourLegendTitle
  • add
  • plotZeroVals
  • ...

Details

By default separate legends are added fro symbol size and colouring on either side of the plot, these can be modified by altering legend parameters.

Examples

Run this code
mapBubbles()
#square symbols
mapBubbles(pch=22)

mapBubbles(dF=getMap(), nameZSize="POP_EST", nameZColour="GEO3")

#change colour
mapBubbles(dF=getMap(), nameZSize="POP_EST", nameZColour="GEO3"
          ,colourPalette='rainbow', oceanCol='lightblue', landCol='wheat') 


data("countryExData",envir=environment(),package="rworldmap")
sPDF <- joinCountryData2Map(countryExData,joinCode = "ISO3"
                           ,nameJoinColumn = "ISO3V10")
                           
mapBubbles(sPDF, nameZSize="POP_EST",nameZColour="BIODIVERSITY"
          ,colourPalette='topo',numCats=5,catMethod="quantiles")

Run the code above in your browser using DataLab