Learn R Programming

rworldmap (version 1.01)

rwmGetClassBreaks: Internal function to set the numeric values for the breaks between data categories

Description

Sets the values that determine how a vector of continuous data is classified into categories. Called by mapCountryData() and mapGriddedData()

Usage

rwmGetClassBreaks(dataColumn, catMethod, numCats, verbose=TRUE, midpoint=0)

Arguments

dataColumn
the data vector to be classified, must be numeric
catMethod
the method to use to classify the data into categories, choice of "pretty", "fixedWidth", "diverging", "logfixedWidth","quantiles","categorical" or a numeric vector defining breaks
numCats
number of categories to put the data in, may be overidden if not possible under some classification methods
verbose
whether to print information messages to console TRUE/FALSE
midpoint
the midpoint to use if catMethod='diverging', default=0

Value

  • A vector specifying the numeric breaks between data categories.

See Also

The classInt package