rwmGetISO3: Internal function for getting the ISO3 country code for a country name synonymn.
Description
Searches countrySynonyms to get the ISO3 code. If the name is not found NA is returned.
Allows joining of imperfect names to other country data in joinCountryData2Map( joinCode='NAME' )
Usage
rwmGetISO3(oddName)
Arguments
oddName
country name that user wishes to find code for
Value
the ISO3 code (3 letters) corresponding to the country name passed, or NA if one is not found
References
This was derived and used with permission from the Perl Locale package. Locale::Codes::Country_Codes.
Thanks to Sullivan Beck for pulling this together.
Data sources are acknowledged here :
http://search.cpan.org/~sbeck/Locale-Codes-3.23/lib/Locale/Codes/Country.pod