Learn R Programming

rworldmap (version 1.01)

rwmNewMapPlot: Internal function to set up an existing device for plotting maps

Description

Sets the region, aspect and ocean colour for a new map plot

Usage

rwmNewMapPlot(mapToPlot, oceanCol, mapRegion, xlim, ylim, aspect)

Arguments

mapToPlot
the worldmap to be plotted
oceanCol
a colour for the ocean
mapRegion
a string specifying the map region, see setMapExtents()
xlim
map extents c(west,east), can be overidden by mapRegion
ylim
map extents c(south,north), can be overidden by mapRegion
aspect
aspect for the map, defaults to 1, if set to 'variable' uses same default as plot.Spatial in sp

Details

Called by mapCountryData() and mapGriddedData()