Learn R Programming

rworldmap (version 1.01)

rworldmap-package: For mapping global data.

Description

Enables mapping of country level and gridded user datasets by facilitating joining to world maps and visualisation options.

Arguments

Details

ll{ Package: rworldmap Type: Package Version: 1.01 Date: 2012-10-1 License: GPL (>= 2) } Version 1.01 October 2012 newly uses updated Natural Earth Data for country boundaries e.g. countriesLow. Higher resolution boundaries are provided in a companion package rworldxtra. It also adds country synonym matching in joinCountryData2Map. Country Level Data can be joined to a map using joinCountryData2Map, then mapped using mapCountryData. Gridded data can be mapped using mapGriddedData. More generic functions allow the user to provide their own polygon map using joinData2Map and mapPolys. Bubble, bar and pie charts can be added to maps using mapBubbles, mapBars and mapPies. Try the new method barplotCountryData for producing a ranked bar plot of country data with country names that can provide a useful companion to maps. Options are provided for categorising data, colouring maps and symbols, and adding legends. Type vignette('rworldmap') to access a short document showing a few examples of the main rworldmap functions to get you started.

References

Stable version : http://cran.r-project.org/web/packages/rworldmap Development version : http://code.google.com/p/rworld

Examples

Run this code
#mapping country level data, with no file specified it uses internal example data
mapCountryData()
#specifying region
mapCountryData(mapRegion="asia")
#mapping gridded data, with no file specified it uses internal example data
mapGriddedData()
#specifying region 
mapGriddedData(mapRegion="africa")  
#aggregating gridded data to country level 
#with no file specified it uses internal example data
mapHalfDegreeGridToCountries()

Run the code above in your browser using DataLab