Learn R Programming

rworldmap (version 1.01)

setMapExtents: Internal function allowing map extents to be set from area names

Description

Allows map extents to be set from country or area names (e.g. India, Africa )

Usage

setMapExtents(mapRegion = "world")

Arguments

mapRegion
a country name from getMap()[['NAME']] or one of 'eurasia','africa','latin america','uk','oceania','asia'

Value

  • a dataframe containing we,ea,so,no values in degrees between -180 & +180

Details

Can be called by mapCountryData and mapGriddedData

Examples

Run this code
mapCountryData( mapRegion='Africa' )
mapCountryData( mapRegion='India' )

Run the code above in your browser using DataLab