countryExData: Example dataset for country level data (2008 Environmental Performance Index)
Description
A dataframe containing example country level data for 149 countries.
This is the 2008 Environmental Performance Index (EPI) downloaded from http://epi.yale.edu/.
Used here with permission, further details on the data can be found there.
The data are referenced by ISO 3 letter country codes and country names.
Usage
data(countryExData)
Arguments
source
http://epi.yale.edu/Downloads
Details
2008 Environmental Performance Index (EPI) data downloaded from : http://epi.yale.edu/Downloads
Disclaimers
This 2008 Environmental Performance Index (EPI) tracks national environmental results on a quantitative basis,
measuring proximity to an established set of policy targets using the best data available. Data constraints
and limitations in methodology make this a work in progress. Further refinements will be undertaken over the
next few years.
Comments, suggestions, feedback, and referrals to better data sources are welcome at:
http://epi.yale.edu or epi@yale.edu.
References
Esty, Daniel C., M.A. Levy, C.H. Kim, A. de Sherbinin, T. Srebotnjak, and V. Mara. 2008.
2008 Environmental Performance Index. New Haven: Yale Center for Environmental Law and Policy.