Usage
mapBubbles(dF = ""
, nameX = "longitude"
, nameY = "latitude"
, nameZSize = ""
, nameZColour = ""
, fill = TRUE
, pch = 21
, symbolSize = 1
, maxZVal = NA
, main = nameZSize
, numCats = 5
, catMethod = "categorical"
, colourPalette = "heat"
, mapRegion = "world"
, borderCol = "grey"
, oceanCol = NA
, landCol = NA
, addLegend = TRUE
, legendBg = "white"
, legendVals = ""
, legendPos = "bottomright"
, legendHoriz = FALSE
, legendTitle = nameZSize
, addColourLegend = TRUE
, colourLegendPos = "bottomleft"
, colourLegendTitle = nameZColour
, add = FALSE
, plotZeroVals = TRUE
, ...)Arguments
dF
data frame or SpatialPolygonsDataFrame
nameX
name of column containing the X variable (longitude), not needed if dF is a SpatialPolygonsDataFrame
nameY
name of column containing the Y variable (lattitude), not needed if dF is a SpatialPolygonsDataFrame
nameZSize
name of column containing numeric variable to set symbol size
nameZColour
name of column containing variable to set symbol colour
fill
whether or not to fill symbols TRUE/FALSE
pch
symbol type, default of 21 for circles, will work with other filled
symbol types e.g. 22=square, 23=diamond, 24=triangle
symbolSize
multiplier of default symbol size
maxZVal
the attribute value corresponding to the maximum symbol size,
this can be used to set the scaling the same between multiple plots
main
title for the map, set to nameZSize by default
numCats
number of categories to put the data in, may be modified if this number is incompatible with the catMethod chosen
catMethod
method for categorisation of data "pretty", "fixedWidth", "diverging", "logfixedWidth","quantiles","categorical", or a numeric vector defining breaks
colourPalette
a string describing the colour palette to use, choice of :
{="palette" for the current palette}
{a vector of valid colours, e.g. =c('red','white','blue') or output from RColourBrewer}
<