the method to use to classify the data into categories, choice of "pretty", "fixedWidth", "diverging", "logfixedWidth","quantiles","categorical" or a numeric vector defining breaks
numCats
number of categories to put the data in, may be overidden if not possible under some classification methods
verbose
whether to print information messages to console TRUE/FALSE
midpoint
the midpoint to use if catMethod='diverging', default=0
Value
A vector specifying the numeric breaks between data categories.